==> bce-java-sdk-0.10.189-sources.jar: com/baidubce/services/iotdmp/model/product/feature/thing/Property.java <==
/*
 * Copyright (C) 2020 Baidu, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */
package com.baidubce.services.iotdmp.model.product.feature.thing;

import com.baidubce.services.iotdmp.model.Constant;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.HashSet;
import java.util.Map;
import java.util.Set;

@Data
@NoArgsConstructor
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
public class Property {

    private static final Set<String> DEFAULT_TYPE = new HashSet<String>() {
        {
            add(Constant.PROPERTY);
        }
    };

    private Map<String, String> dataSchema;
    @JsonProperty("@id")
    private String id = null;
    @JsonProperty("@type")
    private Set<String> type = DEFAULT_TYPE;
    private boolean writable = false;
    private String unit = null;
    private String displayName = null;
    private String description = null;
}

==> bce-java-sdk-0.10.358-sources.jar: com/baidubce/services/iotdmp/model/product/feature/thing/Property.java <==
/*
 * Copyright (C) 2020 Baidu, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */
package com.baidubce.services.iotdmp.model.product.feature.thing;

import com.baidubce.services.iotdmp.model.Constant;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.util.HashSet;
import java.util.Map;
import java.util.Set;

@Data
@NoArgsConstructor
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
public class Property {

    private static final Set<String> DEFAULT_TYPE = new HashSet<String>() {
        {
            add(Constant.PROPERTY);
        }
    };

    private Map<String, Object> dataSchema;
    @JsonProperty("@id")
    private String id = null;
    @JsonProperty("@type")
    private Set<String> type = DEFAULT_TYPE;
    private boolean writable = false;
    private String unit = null;
    private String displayName = null;
    private String description = null;
}
